@@ -117,6 +117,7 @@ public:
      **/
     void setSocketFd(int fd);
 
+
 public Q_SLOTS:
     /**
      * Initializes the connection in an asynchronous way.
@@ -128,6 +129,12 @@ public Q_SLOTS:
      **/
     void initConnection();
 
+    /**
+     * Explicitly flush the Wayland display.
+     * @since 5.3
+     **/
+    void flush();
+
 Q_SIGNALS:
     /**
      * Emitted once a connection to a Wayland server is established.
